"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const fs_1 = __importDefault(require("fs"));
const index_1 = __importDefault(require("./index"));
(0, vitest_1.test)('init', () => {
    const init = new index_1.default();
    (0, vitest_1.expect)(init.name).toBe("MemoryEnmap");
});
(0, vitest_1.test)('basic get and set', () => {
    const db = new index_1.default();
    (0, vitest_1.expect)(db.set('test', 'blah')).toEqual({});
    (0, vitest_1.expect)(db.get('test')).toBe('blah');
    (0, vitest_1.expect)(db.get('nokey')).toBeNull();
});
(0, vitest_1.test)('getters', () => {
    const db = new index_1.default();
    db.set('1', 1);
    db.set('2', 2);
    db.set('3', 3);
    db.set('4', 4);
    db.set('5', 5);
    (0, vitest_1.expect)(db.keys).toEqual(['1', '2', '3', '4', '5']);
    (0, vitest_1.expect)(db.values).toEqual([1, 2, 3, 4, 5]);
    (0, vitest_1.expect)(db.size).toBe(5);
    (0, vitest_1.expect)(['1', '2', '3', '4', '5']).toContain(db.randomKey()[0]);
    (0, vitest_1.expect)(db.has('1')).toBeTruthy();
    (0, vitest_1.expect)(db.has('10')).toBeFalsy();
});
(0, vitest_1.test)('loops', () => {
    const db = new index_1.default();
    db.set('1', 1);
    db.set('2', 2);
    db.set('3', 3);
    db.set('4', 4);
    db.set('5', 5);
    (0, vitest_1.expect)(db.map(v => ++v)).toEqual([2, 3, 4, 5, 6]);
    (0, vitest_1.expect)(db.filter(v => v % 2 === 0)).toEqual([2, 4]);
    (0, vitest_1.expect)(db.find(v => v == 3)).toEqual(3);
    (0, vitest_1.expect)(db.reduce((a, v) => a + v)).toEqual(15);
    (0, vitest_1.expect)(db.reduce((a, v) => a + v, 0)).toEqual(15);
});
(0, vitest_1.test)('modifications', () => {
    const db = new index_1.default();
    db.set('1', 1);
    db.delete('1');
    (0, vitest_1.expect)(db.has('1')).toBeFalsy();
});
(0, vitest_1.test)('import/export', () => {
    const largemock = fs_1.default.readFileSync('./mock/largemock.json', 'utf8');
    const db = new index_1.default();
    const emptyExport = db.export();
    (0, vitest_1.expect)(emptyExport.length).toBe(104);
    db.import(largemock);
    (0, vitest_1.expect)(db.size).toBe(2061);
    const filledExport = db.export();
    (0, vitest_1.expect)(filledExport.length).toBe(109228);
});
