import { assert, expect, test } from 'vitest';

import fs from 'fs'

import Enmap from './index'

test('init', () => {
  const init = new Enmap()
  expect(init.name).toBe("MemoryEnmap")
})

test('basic get and set', () => {
  const db = new Enmap()
  expect(db.set('test', 'blah')).toEqual({})
  expect(db.get('test')).toBe('blah')
  expect(db.get('nokey')).toBeNull()
  
})

test('getters', () => {
  const db = new Enmap()
  db.set('1', 1)
  db.set('2', 2)
  db.set('3', 3)
  db.set('4', 4)
  db.set('5', 5)
  expect(db.keys).toEqual(['1', '2', '3', '4', '5'])
  expect(db.values).toEqual([1, 2, 3, 4, 5])
  expect(db.size).toBe(5)
  expect(['1', '2', '3', '4', '5']).toContain(db.randomKey()[0])

  expect(db.has('1')).toBeTruthy()
  expect(db.has('10')).toBeFalsy()
})

test('loops', () => {
  const db = new Enmap()
  db.set('1', 1)
  db.set('2', 2)
  db.set('3', 3)
  db.set('4', 4)
  db.set('5', 5)
  expect(db.map(v => ++v)).toEqual([2, 3, 4, 5, 6])
  expect(db.filter(v => v % 2 === 0)).toEqual([2, 4])
  expect(db.find(v => v == 3)).toEqual(3)
  expect(db.reduce((a, v) => a + v)).toEqual(15)
  expect(db.reduce((a, v) => a + v, 0)).toEqual(15)
})

test('modifications', () => {
  const db = new Enmap();
  db.set('1', 1);

  db.delete('1')
  expect(db.has('1')).toBeFalsy()
})

test('import/export', () => {
  const largemock = fs.readFileSync('./mock/largemock.json', 'utf8');
  const db = new Enmap();
  const emptyExport = db.export()
  expect(emptyExport.length).toBe(104);
  db.import(largemock);
  expect(db.size).toBe(2061)
  const filledExport = db.export();
  expect(filledExport.length).toBe(109228);
})
